==> haskell-fold-debounce-0.2.0.13-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fold-debounce
version:              0.2.0.13
visibility:           public
id:                   fold-debounce-0.2.0.13-4oETcSmQcf4JuFFMHK4xEj
key:                  fold-debounce-0.2.0.13-4oETcSmQcf4JuFFMHK4xEj
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  19ea4d05f33f5ada2fd80bd8d3324dc7
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.13-4oETcSmQcf4JuFFMHK4xEj
depends:
    base-4.17.2.1 data-default-0.7.1.2-7c115eFpvxq7Z5z0er1qPt
    stm-2.5.1.0 stm-delay-0.1.1.2-BshbHldwy5C1JhGAjrtbMC time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fold-debounce-0.2.0.13-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fold-debounce
version:              0.2.0.13
visibility:           public
id:                   fold-debounce-0.2.0.13-LoURybNzlEN46FgwsdvIZz
key:                  fold-debounce-0.2.0.13-LoURybNzlEN46FgwsdvIZz
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  b91c82f175a1de67612b65ce8c9ecc9d
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fold-debounce-0.2.0.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.13-LoURybNzlEN46FgwsdvIZz
depends:
    base-4.17.2.1 data-default-0.7.1.2-8zpNuXeugnsCXhsU9L7wsy
    stm-2.5.1.0 stm-delay-0.1.1.2-HFD1tHD6PAEKDMrbAcKSBm time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
